/*
 * ProGuard -- shrinking, optimization, obfuscation, and preverification
 *             of Java bytecode.
 *
 * Copyright (c) 2002-2010 Eric Lafortune (eric@graphics.cornell.edu)
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package proguard.io;

import proguard.classfile.ClassConstants;
import proguard.util.ExtensionMatcher;

import java.io.IOException;


/**
 * This DataEntryReader delegates to one of two other DataEntryReader instances,
 * depending on the extension of the data entry.
 *
 * @author Eric Lafortune
 */
public class ClassFilter extends FilteredDataEntryReader
{
    /**
     * Creates a new ClassFilter that delegates reading classes to the
     * given reader.
     */
    public ClassFilter(DataEntryReader classReader)
    {
        this(classReader, null);
    }


    /**
     * Creates a new ClassFilter that delegates to either of the two given
     * readers.
     */
    public ClassFilter(DataEntryReader classReader,
                       DataEntryReader dataEntryReader)
    {
        super(new DataEntryNameFilter(
              new ExtensionMatcher(ClassConstants.CLASS_FILE_EXTENSION)),
              classReader,
              dataEntryReader);
    }
}
